"""
Image Slicer
~~~~~~~~~~~~

Chop up images. Merge them back together. Basic usage:

   >>> import image_slicer
   >>> print('example goes here')
   example goes here

:copyright: (c) 2013 Sam Dobson.
:license: MIT, see LICENSE for more details.

"""

__title__ = 'image_slicer'
__author__ = 'Sam Dobson'
__license__ = 'MIT'
__copyright__ = 'Copyright 2013 Sam Dobson'

from .main import *
from .helpers import *

